==> okapi-ir-0.1.6-sources.jar: org/opencypher/okapi/ir/api/block/ProjectBlock.scala <==
/*
 * Copyright (c) 2016-2018 "Neo4j Sweden, AB" [https://neo4j.com]
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Attribution Notice under the terms of the Apache License 2.0
 *
 * This work was created by the collective efforts of the openCypher community.
 * Without limiting the terms of Section 6, any Derivative Work that is not
 * approved by the public consensus process of the openCypher Implementers Group
 * should not be described as “Cypher” (and Cypher® is a registered trademark of
 * Neo4j Inc.) or as "openCypher". Extensions by implementers or prototypes or
 * proposals for change that have been documented or implemented should only be
 * described as "implementation extensions to Cypher" or as "proposed changes to
 * Cypher that are not yet approved by the openCypher community".
 */
package org.opencypher.okapi.ir.api.block

import org.opencypher.okapi.ir.api._

final case class ProjectBlock[E](
    after: List[Block[E]],
    binds: Fields[E] = Fields[E](),
    where: Set[E] = Set.empty[E],
    graph: IRGraph,
    distinct: Boolean = false
) extends BasicBlock[Fields[E], E](BlockType("project"))

final case class Fields[E](items: Map[IRField, E] = Map.empty[IRField, E]) extends Binds[E] {
  override def fields: Set[IRField] = items.keySet
}

case object ProjectedFieldsOf {
  def apply[E](entries: (IRField, E)*) = Fields(entries.toMap)
}

==> okapi-ir-0.2.3-sources.jar: org/opencypher/okapi/ir/api/block/ProjectBlock.scala <==
/*
 * Copyright (c) 2016-2018 "Neo4j Sweden, AB" [https://neo4j.com]
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Attribution Notice under the terms of the Apache License 2.0
 *
 * This work was created by the collective efforts of the openCypher community.
 * Without limiting the terms of Section 6, any Derivative Work that is not
 * approved by the public consensus process of the openCypher Implementers Group
 * should not be described as “Cypher” (and Cypher® is a registered trademark of
 * Neo4j Inc.) or as "openCypher". Extensions by implementers or prototypes or
 * proposals for change that have been documented or implemented should only be
 * described as "implementation extensions to Cypher" or as "proposed changes to
 * Cypher that are not yet approved by the openCypher community".
 */
package org.opencypher.okapi.ir.api.block

import org.opencypher.okapi.ir.api._
import org.opencypher.okapi.ir.api.expr.Expr

final case class ProjectBlock(
    after: List[Block],
    binds: Fields = Fields(),
    where: Set[Expr] = Set.empty[Expr],
    graph: IRGraph,
    distinct: Boolean = false
) extends BasicBlock[Fields](BlockType("project"))

final case class Fields(items: Map[IRField, Expr] = Map.empty[IRField, Expr]) extends Binds {
  override def fields: Set[IRField] = items.keySet
}

case object ProjectedFieldsOf {
  def apply(entries: (IRField, Expr)*) = Fields(entries.toMap)
}
